@@ -12,7 +12,7 @@ def expose_service(methods, public=False):
         def wrapper(request, *args, **kwargs):
             error_message = None
             code = 500
-            
+
             try:
                 if hasattr(settings, 'PROXY_API_KEYS'):
                     if request.META.get(proxy_server.HTTP_API_KEY) in settings.PROXY_API_KEYS:
@@ -33,7 +33,7 @@ def expose_service(methods, public=False):
                                     try:
                                         dot = settings.PROXY_TOKEN_VALIDATION_SERVICE.rindex('.')
                                     except ValueError:
-                                        error_message ='Token validation service not properly configured'
+                                        error_message = 'Token validation service not properly configured'
                                         raise Exception
 
                                     val_module = import_module(settings.PROXY_TOKEN_VALIDATION_SERVICE[:dot])
@@ -45,6 +45,11 @@ def expose_service(methods, public=False):
                                         error_message = 'Could not invoke token validation service'
                                         raise Exception
 
+                                    if response.status_code == 403:
+                                        code = 403
+                                        error_message = 'Token invalid'
+                                        raise Exception
+
                                     response_json = json.loads(response.content)
                                     request.META[proxy_server.HTTP_USER_TOKEN] = response_json[proxy_server.USER_TOKEN]
                                     return api_view(methods)(view_func)(request, *args, **kwargs)
